@@ -1,3 +1,4 @@
+#![allow(missing_docs)]
 use std::path::PathBuf;
 
 use crate::Kind;
@@ -8,14 +9,14 @@ pub use is_git::{is_bare, is_git};
 
 #[derive(Debug, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
 pub enum Path {
-    WorkingTree(PathBuf),
+    WorkTree(PathBuf),
     Repository(PathBuf),
 }
 
 impl AsRef<std::path::Path> for Path {
     fn as_ref(&self) -> &std::path::Path {
         match self {
-            Path::WorkingTree(path) | Path::Repository(path) => path,
+            Path::WorkTree(path) | Path::Repository(path) => path,
         }
     }
 }
@@ -24,20 +25,20 @@ impl Path {
     pub fn from_dot_git_dir(dir: impl Into<PathBuf>, kind: Kind) -> Self {
         let dir = dir.into();
         match kind {
-            Kind::WorkingTree => Path::WorkingTree(dir.parent().expect("this is a sub-directory").to_owned()),
+            Kind::WorkTree => Path::WorkTree(dir.parent().expect("this is a sub-directory").to_owned()),
             Kind::Bare => Path::Repository(dir),
         }
     }
     pub fn kind(&self) -> Kind {
         match self {
-            Path::WorkingTree(_) => Kind::WorkingTree,
+            Path::WorkTree(_) => Kind::WorkTree,
             Path::Repository(_) => Kind::Bare,
         }
     }
 
     pub fn into_repository_directory(self) -> PathBuf {
         match self {
-            Path::WorkingTree(path) => path.join(".git"),
+            Path::WorkTree(path) => path.join(".git"),
             Path::Repository(path) => path,
         }
     }
